Learn R Programming

oxcAAR (version 1.1.2)

Boundary: Returns the Oxcal code for a Boundary

Description

Boundary returns the OxCal code for a Boundary. For details concerning the Oxcal simulation please consult the help page of Oxcal.

Usage

Boundary(names = "")

Value

a string containing the respective Oxcal code

Arguments

names

a optional vector of names for the resulting boundary. If missing or empty, an unnamed boundary is returned.