Learn R Programming

oxcAAR (version 1.1.2)

oxcAARCalibratedDate: oxcAAR Calibrated Dates Object

Description

The function oxcAARCalibratedDate() creates an object representing a single calibrated radiocarbon date (and optionally its posterior, if a model was run in OxCal).

Usage

oxcAARCalibratedDate(
  name,
  type,
  bp,
  std,
  cal_curve,
  sigma_ranges,
  raw_probabilities,
  posterior_probabilities = NA,
  posterior_sigma_ranges = NA
)

Value

An object of class "oxcAARCalibratedDate".

Arguments

name

A string giving the name of the date (usually the lab number).

type

A string giving the type of the date in OxCal terminology (e.g. "R_Date", "R_Simulate").

bp

An integer/numeric giving the uncalibrated BP value.

std

An integer/numeric giving the standard deviation.

cal_curve

A list with calibration curve information (name, resolution, bp, bc, sigma).

sigma_ranges

A list of three elements (one, two, three sigma), each a data frame with columns start, end, probability.

raw_probabilities

A data frame with columns dates and probabilities.

posterior_probabilities

A data frame with columns dates and probabilities, or NA if not available.

posterior_sigma_ranges

A list of three elements (one, two, three sigma), each a data frame with columns start, end, probability, or NA if not available.