oxcalCalibrate: Calibrates a 14C date using oxcal
Description
Calibrates a 14C date using oxcal
Usage
oxcalCalibrate(bp, std, names = 1:length(bp))
Value
An object of class oxcAARCalibratedDatesList
Arguments
- bp
A vector containing the bp dates of the measurements
- std
A vector containing the standard deviations of the measurements
- names
The names of the measurements, usually the Laboratory numbers