oxcal_Sum: Wraps an Oxcal string into a Oxcal sum function
Description
Wraps an Oxcal string into a Oxcal sum function
Usage
oxcal_Sum(oxcal_string, name = " Sum ")
Value
A new oxcal script as string
Arguments
- oxcal_string
The Oxcal script that should be wrapped (vector or single string)
- name
The name attribute for the resulting sum function