powered by
Boundary returns the OxCal code for a Boundary. For details concerning the Oxcal simulation please consult the help page of Oxcal.
Boundary(names = "")
a string containing the respective Oxcal code
a optional vector of names for the resulting boundary. If missing or empty, an unnamed boundary is returned.