The function oxcAARCalibratedDate() creates an object representing a single
calibrated radiocarbon date (and optionally its posterior, if a model was run in OxCal).
oxcAARCalibratedDate(
name,
type,
bp,
std,
cal_curve,
sigma_ranges,
raw_probabilities,
posterior_probabilities = NA,
posterior_sigma_ranges = NA
)An object of class "oxcAARCalibratedDate".
A string giving the name of the date (usually the lab number).
A string giving the type of the date in OxCal terminology (e.g. "R_Date", "R_Simulate").
An integer/numeric giving the uncalibrated BP value.
An integer/numeric giving the standard deviation.
A list with calibration curve information (name, resolution, bp, bc, sigma).
A list of three elements (one, two, three sigma), each a data frame
with columns start, end, probability.
A data frame with columns dates and probabilities.
A data frame with columns dates and probabilities,
or NA if not available.
A list of three elements (one, two, three sigma), each a data frame
with columns start, end, probability, or NA if not available.